@@ -10,7 +10,7 @@ The examples use the following sample tasks file:
 ...  .
 ...  This is however incomplete.
 ...
-... Recommends: celestia-gnome | celestia-glut, starplot
+... Recommends: celestia-gnome | celestia-glut, kstars
 ...
 ... Recommends: gravit
 ... WNPP: 743379
@@ -208,7 +208,7 @@ class Task:
     ...     print(p.name)
     celestia-gnome
     celestia-glut
-    starplot
+    kstars
     gravit
     sunclock
     xtide
@@ -252,8 +252,8 @@ class Task:
             self.format_upgraded = True
 
         # Create package dependencies
-        dep_types = ["Depends", "Recommends", "Suggests"]
-        dep_attrs = ["dependencies", "recommends", "suggests"]
+        dep_types = ["Depends", "Recommends", "Suggests", "Conflicts", "Breaks"]
+        dep_attrs = ["dependencies", "recommends", "suggests", "conflicts", "breaks"]
         for dep_type, dep_attr in zip(dep_types, dep_attrs):
             setattr(self, dep_attr, list(itertools.chain(
                 *(list(Dependency(dep_type, s.strip(), par)
@@ -354,7 +354,7 @@ class Task:
         Architecture: all
         Recommends: celestia-gnome | celestia-glut,
                     gravit,
-                    starplot
+                    kstars
         Suggests: sunclock,
                   xtide
         Description: Educational astronomy applications
@@ -380,6 +380,14 @@ class Task:
             d['Suggests'] = ",\n          ".join(sorted(
                 set(d.rawstr for d in self.suggests)
             ))
+        if self.conflicts:
+            d['Conflicts'] = ",\n           ".join(sorted(
+                set(d.rawstr for d in self.conflicts)
+            ))
+        if self.breaks:
+            d['Breaks'] = ",\n        ".join(sorted(
+                set(d.rawstr for d in self.breaks)
+            ))
         d['Description'] = self.summary + '\n ' + \
             "\n ".join(self.description.replace("\n\n", "\n.\n").split("\n"))
         return d
@@ -438,10 +446,11 @@ class Task:
         ...     task = Task('debian-astro', 'education', fp)
         >>> dep = task.recommends[1][0]
         >>> print(dep.name + ": ", dep.summary)
-        starplot:  None
+        kstars:  None
         >>> task += apt.Cache()
         >>> print(dep.name + ": ", dep.summary)
-        starplot:  3-dimensional perspective star map viewer
+        kstars:  desktop planetarium, observation planning and telescope control
+
         '''
         for dep in self.all:
             pkg = cache.get(dep.name)
@@ -467,7 +476,7 @@ class Task:
         >>> for dep in task.recommends:
         ...     print(dep.rawstr)
         celestia-gnome | celestia-glut
-        starplot
+        kstars
         gravit
         >>> for dep in task.suggests:
         ...     print(dep.rawstr)
@@ -477,7 +486,7 @@ class Task:
         >>> missing = task.fix_dependencies()
         >>> for dep in task.recommends:
         ...     print(dep.rawstr)
-        starplot
+        kstars
         gravit
         >>> for dep in task.suggests:
         ...     print(dep.rawstr)
